@@ -1690,13 +1690,21 @@ class DebuggerUI(object):
         except ImportError:
             HAVE_NUMPY = 0
 
+        watch_prefixes = []
+
         def add_var(prefix, var_label, value_str, id_path=None, attr_prefix=None):
             iinfo = id_path_to_iinfo.get(id_path, InspectInfo())
             if iinfo.highlighted:
                 attr_prefix = "highlighted var"
 
-            if iinfo.watched:
+            watched = iinfo.watched
+            for wp in watch_prefixes:
+                if id_path.startswith(wp):
+                    watched = True
+
+            if watched:
                 watch_list.append(Variable(prefix, var_label, value_str, id_path, attr_prefix))
+                watch_prefixes.append(id_path)
 
             loc_list.append(Variable(prefix, var_label, value_str, id_path, attr_prefix))
 
@@ -1713,22 +1721,20 @@ class DebuggerUI(object):
             elif isinstance(value, type):
                 add_var(prefix, label, "type "+value.__name__, id_path, attr_prefix)
             else:
-                if isinstance(value, numpy.ndarray):
-                    add_var(prefix, label,
-                        "ndarray %s %s" % (value.dtype, value.shape),
-                        id_path, attr_prefix)
-                else:
-                    if iinfo.display_type == "type":
-                        displayed_value = type(value).__name__
-                    elif iinfo.display_type == "repr":
-                        displayed_value = repr(value)
-                    elif iinfo.display_type == "str":
-                        displayed_value = str(value)
+                if iinfo.display_type == "type":
+                    if HAVE_NUMPY and isinstance(value, numpy.ndarray):
+                        displayed_value = "ndarray %s %s" % (value.dtype, value.shape)
                     else:
-                        displayed_value = "ERROR: Invalid display_type"
+                        displayed_value = type(value).__name__
+                elif iinfo.display_type == "repr":
+                    displayed_value = repr(value)
+                elif iinfo.display_type == "str":
+                    displayed_value = str(value)
+                else:
+                    displayed_value = "ERROR: Invalid display_type"
 
-                    add_var(prefix, label,
-                        displayed_value, id_path, attr_prefix)
+                add_var(prefix, label,
+                    displayed_value, id_path, attr_prefix)
 
                 if not iinfo.show_detail:
                     return
